[][src]Enum pyo3_pack::BridgeModel

pub enum BridgeModel {
    Cffi,
    Bin,
    Bindings(String),
}

The way the rust code is used in the wheel

Variants

Cffi

A native module with c bindings, i.e. #[no_mangle] extern "C" <some item>

Bin

A rust binary to be shipped a python package

Bindings(String)

A native module with pyo3 or rust-cpython bindings. The String is the name of the bindings providing crate, e.g. pyo3.

Methods

impl BridgeModel[src]

pub fn unwrap_bindings(&self) -> &str[src]

Returns the name of the bindings crate