[−][src]Struct pyo3_pack::BuildOptions
High level API for building wheels from a crate which is also used for the CLI
Fields
manylinux: ManylinuxControl the platform tag on linux.
1: Use the manylinux1 tag and check for compliance{n}1-unchecked: Use the manylinux1 tag without checking for compliance{n}2010: Use the manylinux2010 tag and check for compliance{n}2010-unchecked: Use the manylinux1 tag without checking for compliance{n}off: Use the native linux tag (off)
This option is ignored on all non-linux platforms
interpreter: Vec<String>The python versions to build wheels for, given as the names of the interpreters. Uses autodiscovery if not explicitly set.
bindings: Option<String>Which kind of bindings to use. Possible values are pyo3, rust-cpython, cffi and bin
manifest_path: PathBufThe path to the Cargo.toml
out: Option<PathBuf>The directory to store the built wheels in. Defaults to a new "wheels" directory in the project's target directory
skip_auditwheel: bool[deprecated, use --manylinux instead] Don't check for manylinux compliance
target: Option<String>The --target option for cargo
cargo_extra_args: Vec<String>Extra arguments that will be passed to cargo as cargo rustc [...] [arg1] [arg2] --
Use as --cargo-extra-args="--my-arg"
rustc_extra_args: Vec<String>Extra arguments that will be passed to rustc as cargo rustc [...] -- [arg1] [arg2]
Use as --rustc-extra-args="--my-arg"
Methods
impl BuildOptions[src]
pub fn into_build_context(
self,
release: bool,
strip: bool
) -> Result<BuildContext, Error>[src]
self,
release: bool,
strip: bool
) -> Result<BuildContext, Error>
Tries to fill the missing metadata for a BuildContext by querying cargo and python