[−][src]Struct pyo3_pack::Metadata21
Python Package Metadata 2.1 as specified in https://packaging.python.org/specifications/core-metadata/
Fields
metadata_version: Stringname: Stringversion: Stringplatform: Vec<String>supported_platform: Vec<String>summary: Option<String>description: Option<String>description_content_type: Option<String>keywords: Option<String>home_page: Option<String>download_url: Option<String>maintainer: Option<String>maintainer_email: Option<String>license: Option<String>classifier: Vec<String>requires_dist: Vec<String>provides_dist: Vec<String>obsoletes_dist: Vec<String>requires_python: Option<String>requires_external: Vec<String>project_url: Vec<String>provides_extra: Vec<String>Methods
impl Metadata21[src]
pub fn from_cargo_toml(
cargo_toml: &CargoToml,
manifest_path: &Path
) -> Result<Metadata21, Error>[src]
cargo_toml: &CargoToml,
manifest_path: &Path
) -> Result<Metadata21, Error>
Uses a Cargo.toml to create the metadata for python packages
manifest_path must be the directory, not the file
pub fn to_vec(&self) -> Vec<(String, String)>[src]
Formats the metadata into a list of key with multiple values have mutliple singel-valued pairs. This format is needed for the pypi uploader and for the metadata file inside wheels
pub fn to_file_contents(&self) -> String[src]
Writes the format for the metadata file inside wheels
pub fn get_distribution_escaped(&self) -> String[src]
Returns the distribution name according to PEP 427, Section "Escaping and Unicode"
pub fn get_version_escaped(&self) -> String[src]
Returns the version encoded according to PEP 427, Section "Escaping and Unicode"