Struct pyo3_pack::WheelMetadata[][src]

pub struct WheelMetadata {
    pub metadata21: Metadata21,
    pub scripts: HashMap<String, String>,
    pub module_name: String,
}

The metadata required to generate the .dist-info directory

Fields

Python Package Metadata 2.1

The [console_scripts] for the entry_points.txt

The name of the module can be distinct from the package name, mostly because package names normally contain minuses while module names have underscores. The package name is part of metadata21