Enum pyo3_pack::UploadError[][src]

pub enum UploadError {
    RewqestError(Error),
    AuthenticationError,
    IOError(Error),
    StatusCodeError(String),
}

Error type for different types of errors that can happen when uploading a wheel.

The most interesting tpye is AuthenticationError because it allows asking the user to reenter the password

Variants

Any reqwest error

The registry returned a "403 Forbidden"

Reading the wheel failed

The registry returned something else than 200