Enum pyo3_pack::UploadError [−][src]
pub enum UploadError {
RewqestError(Error),
AuthenticationError,
IOError(Error),
StatusCodeError(String),
}Error type for different types of errors that can happen when uploading a wheel.
The most interesting tpye is AuthenticationError because it allows asking the user to reenter the password
Variants
RewqestError(Error)Any reqwest error
AuthenticationErrorThe registry returned a "403 Forbidden"
IOError(Error)Reading the wheel failed
StatusCodeError(String)The registry returned something else than 200