Struct pyo3_pack::BuildContext [−][src]
pub struct BuildContext {
pub interpreter: Vec<String>,
pub binding_crate: String,
pub manifest_path: PathBuf,
pub wheel_dir: Option<PathBuf>,
pub use_cached: bool,
pub debug: bool,
pub skip_auditwheel: bool,
}High level API for building wheels from a crate which can be also used for the CLI
Fields
interpreter: Vec<String>
The python versions to build wheels for, given as the names of the interpreters. Uses a built-in list if not explicitly set.
binding_crate: String
The crate providing the python bindings
manifest_path: PathBuf
The path to the Cargo.toml or the directory containing it
wheel_dir: Option<PathBuf>
The directory to store the built wheels in. Defaults to a new "wheels" directory in the project's target directory
use_cached: bool
Don't rebuild if a wheel with the same name is already present
debug: bool
Do a debug build (don't pass --release to cargo)
skip_auditwheel: bool
Don't check for manylinux compliance
Methods
impl BuildContext[src]
impl BuildContextpub fn build_wheels(
self
) -> Result<(Vec<(PathBuf, Option<PythonInterpreter>)>, WheelMetadata), Error>[src]
pub fn build_wheels(
self
) -> Result<(Vec<(PathBuf, Option<PythonInterpreter>)>, WheelMetadata), Error>Builds wheels for a Cargo project for all given python versions. Returns the paths where the wheels are saved and the Python metadata describing the cargo project
Defaults to 2.7 and 3.{5, 6, 7, 8, 9} if not python versions are given and silently ignores all non-existent python versions. Runs auditwheel_rs().if the auditwheel feature isn't deactivated