Struct pyo3_pack::BuildOptions [−][src]
pub struct BuildOptions {
pub interpreter: Vec<String>,
pub bindings: Option<String>,
pub manifest_path: PathBuf,
pub out: Option<PathBuf>,
pub debug: bool,
pub skip_auditwheel: bool,
pub cargo_extra_args: Vec<String>,
pub rustc_extra_args: Vec<String>,
}High level API for building wheels from a crate which can be also used for the CLI
Fields
interpreter: Vec<String>
The python versions to build wheels for, given as the names of the interpreters. Uses autodiscovery if not explicitly set.
bindings: Option<String>
The crate providing the python bindings. pyo3, rust-cpython and cffi are supported
manifest_path: PathBuf
The path to the Cargo.toml
out: Option<PathBuf>
The directory to store the built wheels in. Defaults to a new "wheels" directory in the project's target directory
debug: bool
Do a debug build (don't pass --release to cargo)
skip_auditwheel: bool
Don't check for manylinux compliance
cargo_extra_args: Vec<String>
Extra arguments that will be passed to cargo as cargo rustc [...] [arg1] [arg2] --
rustc_extra_args: Vec<String>
Extra arguments that will be passed to rustc as cargo rustc [...] -- [arg1] [arg2]
Methods
impl BuildOptions[src]
impl BuildOptionspub fn into_build_context(self) -> Result<BuildContext, Error>[src]
pub fn into_build_context(self) -> Result<BuildContext, Error>Tries to fill the missing metadata in BuildContext by querying cargo and python