Struct pyo3_pack::Metadata21[][src]

pub struct Metadata21 {
    pub metadata_version: String,
    pub name: String,
    pub version: String,
    pub platform: Vec<String>,
    pub supported_platform: Vec<String>,
    pub summary: Option<String>,
    pub description: Option<String>,
    pub description_content_type: Option<String>,
    pub keywords: Option<String>,
    pub home_page: Option<String>,
    pub download_url: Option<String>,
    pub author: Option<String>,
    pub author_email: Option<String>,
    pub maintainer: Option<String>,
    pub maintainer_email: Option<String>,
    pub license: Option<String>,
    pub classifier: Vec<String>,
    pub requires_dist: Vec<String>,
    pub provides_dist: Vec<String>,
    pub obsoletes_dist: Vec<String>,
    pub requires_python: Option<String>,
    pub requires_external: Vec<String>,
    pub project_url: Vec<String>,
    pub provides_extra: Vec<String>,
}

Python Package Metadata 2.1 as specified in https://packaging.python.org/specifications/core-metadata/

Fields

Methods

impl Metadata21
[src]

Uses a Cargo.Toml to create the metadata for python packages

manifest_path must be the directory, not the file

Formats the metadata into a list of key with multiple values have mutliple singel-valued pairs. This format is needed for the pypi uploader and for the metadata file inside wheels

Writes the format for the metadata file inside wheels

Returns the distribution name according to PEP 427, Section "Escaping and Unicode"