Struct pyo3_pack::Metadata21 [−][src]
pub struct Metadata21 {
pub metadata_version: String,
pub name: String,
pub version: String,
pub platform: Vec<String>,
pub supported_platform: Vec<String>,
pub summary: Option<String>,
pub description: Option<String>,
pub description_content_type: Option<String>,
pub keywords: Option<String>,
pub home_page: Option<String>,
pub download_url: Option<String>,
pub author: Option<String>,
pub author_email: Option<String>,
pub maintainer: Option<String>,
pub maintainer_email: Option<String>,
pub license: Option<String>,
pub classifier: Vec<String>,
pub requires_dist: Vec<String>,
pub provides_dist: Vec<String>,
pub obsoletes_dist: Vec<String>,
pub requires_python: Option<String>,
pub requires_external: Vec<String>,
pub project_url: Vec<String>,
pub provides_extra: Vec<String>,
}Python Package Metadata 2.1 as specified in https://packaging.python.org/specifications/core-metadata/
Fields
metadata_version: String
name: String
version: String
platform: Vec<String>
supported_platform: Vec<String>
summary: Option<String>
description: Option<String>
description_content_type: Option<String>
keywords: Option<String>
home_page: Option<String>
download_url: Option<String>
maintainer: Option<String>
maintainer_email: Option<String>
license: Option<String>
classifier: Vec<String>
requires_dist: Vec<String>
provides_dist: Vec<String>
obsoletes_dist: Vec<String>
requires_python: Option<String>
requires_external: Vec<String>
project_url: Vec<String>
provides_extra: Vec<String>
Methods
impl Metadata21[src]
impl Metadata21pub fn from_cargo_toml(
cargo_toml: &CargoToml,
manifest_path: &Path
) -> Result<Metadata21, Error>[src]
pub fn from_cargo_toml(
cargo_toml: &CargoToml,
manifest_path: &Path
) -> Result<Metadata21, Error>Uses a Cargo.Toml to create the metadata for python packages
manifest_path must be the directory, not the file
pub fn to_vec(&self) -> Vec<(String, String)>[src]
pub fn to_vec(&self) -> Vec<(String, String)>Formats the metadata into a list of key with multiple values have mutliple singel-valued pairs. This format is needed for the pypi uploader and for the metadata file inside wheels
pub fn to_file_contents(&self) -> String[src]
pub fn to_file_contents(&self) -> StringWrites the format for the metadata file inside wheels
pub fn get_distribution_escaped(&self) -> String[src]
pub fn get_distribution_escaped(&self) -> StringReturns the distribution name according to PEP 427, Section "Escaping and Unicode"