Struct pyo3_pack::PythonInterpreter[][src]

pub struct PythonInterpreter {
    pub major: usize,
    pub minor: usize,
    pub has_u: bool,
    pub executable: PathBuf,
}

The location and version of an interpreter

Fields

Python's major version

Python's minor version

The abi; There are e.g. python2.7m and python2.7mu; Other abis are not supported.

See PEP 261 and PEP 393 for details

Path to the python interpreter, e.g. /usr/bin/python3.6

Just the name of the binary in PATH does also work, e.g. python3.5

Methods

impl PythonInterpreter
[src]

Returns the supported python environment in the PEP 425 format: {python tag}-{abi tag}-{platform tag}

Checks which python version of a set of possible versions are avaible and determins whether they are m or mu