Struct pyo3_pack::PythonInterpreter [−][src]
pub struct PythonInterpreter {
pub major: usize,
pub minor: usize,
pub has_u: bool,
pub executable: PathBuf,
}The location and version of an interpreter
Fields
major: usize
Python's major version
minor: usize
Python's minor version
has_u: bool
The abi; There are e.g. python2.7m and python2.7mu; Other abis are not supported.
See PEP 261 and PEP 393 for details
executable: PathBuf
Path to the python interpreter, e.g. /usr/bin/python3.6
Just the name of the binary in PATH does also work, e.g. python3.5
Methods
impl PythonInterpreter[src]
impl PythonInterpreterpub fn get_tag(&self) -> String[src]
pub fn get_tag(&self) -> StringReturns the supported python environment in the PEP 425 format: {python tag}-{abi tag}-{platform tag}
pub fn find_all(
python_versions: &[String]
) -> Result<Vec<PythonInterpreter>, Error>[src]
pub fn find_all(
python_versions: &[String]
) -> Result<Vec<PythonInterpreter>, Error>Checks which python version of a set of possible versions are avaible and determins whether they are m or mu