[−][src]Struct pyo3_pack::Target
The part of the current platform that is relevant when building wheels and is supported
Methods
impl Target[src]
pub fn current() -> Self[src]
Returns the target pyo3-pack was compiled for
pub fn from_target_triple(target_triple: Option<String>) -> Result<Self, Error>[src]
Uses the given target triple or tries the guess the current target by using the one used for compilation
Fails if the target triple isn't supported
pub fn pointer_width(&self) -> usize[src]
Returns whether the platform is 64 bit or 32 bit
pub fn is_unix(&self) -> bool[src]
Returns true if the current platform is linux or mac os
pub fn is_linux(&self) -> bool[src]
Returns true if the current platform is linux
pub fn is_macos(&self) -> bool[src]
Returns true if the current platform is mac os
pub fn is_windows(&self) -> bool[src]
Returns true if the current platform is windows
pub fn get_platform_tag(&self, manylinux: &Manylinux) -> &'static str[src]
Returns the platform part of the tag for the wheel name for cffi wheels
pub fn get_py2_and_py3_tags(&self, manylinux: &Manylinux) -> Vec<String>[src]
Returns the tags for the WHEEL file for cffi wheels
pub fn get_shared_platform_tag(&self) -> &'static str[src]
Returns the platform for the tag in the shared libaries file name
pub fn get_venv_python(
&self,
venv_base: impl AsRef<Path>
) -> PathBuf[src]
&self,
venv_base: impl AsRef<Path>
) -> PathBuf
Returns the path to the python executable inside a venv
pub fn get_venv_bin_dir(
&self,
venv_base: impl AsRef<Path>
) -> PathBuf[src]
&self,
venv_base: impl AsRef<Path>
) -> PathBuf
Returns the directory where the binaries are stored inside a venv
pub fn get_python(&self) -> PathBuf[src]
Returns the path to the python executable
For windows it's always python.exe for unix it's 1. venv's python 2. python3