Struct pyo3_pack::Target[][src]

pub struct Target { /* fields omitted */ }

The part of the current platform that is relevant when building wheels and is supported

Methods

impl Target
[src]

Returns the target pyo3-pack was compiled for

Returns whether the platform is 64 bit or 32 bit

Returns true if the current platform is linux or mac os

Returns true if the current platform is linux

Returns true if the current platform is mac os

Returns true if the current platform is windows

Returns the platform part of the tag for the wheel name for cffi wheels

Returns the tags for the WHEEL file for cffi wheels

Returns the platform for the tag in the shared libaries file name

Returns the path to the python executable inside a venv

Returns the path to the python executable

For windows it's always python.exe for unix it's 1. venv's python 2. python3