Struct pyo3_pack::Target [−][src]
pub struct Target { /* fields omitted */ }The part of the current platform that is relevant when building wheels and is supported
Methods
impl Target[src]
impl Targetpub fn current() -> Self[src]
pub fn current() -> SelfReturns the target pyo3-pack was compiled for
pub fn pointer_width(&self) -> usize[src]
pub fn pointer_width(&self) -> usizeReturns whether the platform is 64 bit or 32 bit
pub fn is_unix(&self) -> bool[src]
pub fn is_unix(&self) -> boolReturns true if the current platform is linux or mac os
pub fn is_linux(&self) -> bool[src]
pub fn is_linux(&self) -> boolReturns true if the current platform is linux
pub fn is_macos(&self) -> bool[src]
pub fn is_macos(&self) -> boolReturns true if the current platform is mac os
pub fn is_windows(&self) -> bool[src]
pub fn is_windows(&self) -> boolReturns true if the current platform is windows
pub fn get_platform_tag(&self) -> &'static str[src]
pub fn get_platform_tag(&self) -> &'static strReturns the platform part of the tag for the wheel name for cffi wheels
Returns the tags for the WHEEL file for cffi wheels
Returns the platform for the tag in the shared libaries file name
pub fn get_venv_python(
&self,
venv_base: impl AsRef<Path>
) -> PathBuf[src]
pub fn get_venv_python(
&self,
venv_base: impl AsRef<Path>
) -> PathBufReturns the path to the python executable inside a venv
pub fn get_python(&self) -> PathBuf[src]
pub fn get_python(&self) -> PathBufReturns the path to the python executable
For windows it's always python.exe for unix it's 1. venv's python 2. python3